/*
 * Copyright 2010 by Kappich Systemberatung Aachen
 * 
 * This file is part of de.bsvrz.pua.prot.
 * 
 * de.bsvrz.pua.prot is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * de.bsvrz.pua.prot is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.pua.prot.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.bsvrz.pua.prot.data;

import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.config.ObjectLookup;
import de.bsvrz.dav.daf.main.config.SystemObject;

/**
 * @author Kappich Systemberatung
 * @version $Revision: 0000 $
 */
class ProtocolDataReferenceValue extends ProtocolDataUnscaledValue implements Data.ReferenceValue {

	/**
	 * Referenz-Ansicht auf ein Datum
	 *
	 * @param attributeProtocolData Datum
	 */
	public ProtocolDataReferenceValue(final AttributeProtocolData attributeProtocolData) {
		super(attributeProtocolData);
	}

	public String getSystemObjectPid() {
		final SystemObject systemObject = getSystemObject();
		if(systemObject == null) return "";
		return systemObject.getPid();
	}

	public SystemObject getSystemObject() {
		long id = getId();
		if(id == 0) return null;
		return _data.getDataModel().getObject(id);
	}

	public long getId() {
		long l = longValue();
		return l == -1 ? 0 : l;
	}

	public void setSystemObject(final SystemObject object) {
		throw new UnsupportedOperationException(ProtocolData.MESSAGE_NO_CHANGE);
	}

	public void setSystemObjectPid(final String objectPid, final ObjectLookup datamodel) {
		throw new UnsupportedOperationException(ProtocolData.MESSAGE_NO_CHANGE);
	}

	public void setSystemObjectPid(final String objectPid) {
		throw new UnsupportedOperationException(ProtocolData.MESSAGE_NO_CHANGE);
	}

	@Override
	public String getValueText() {
		/** kopiert aus {@link de.bsvrz.dav.daf.communication.dataRepresentation.data.info.version1.ReferenceDefinitionInfo} **/
		try {
			SystemObject object = getSystemObject();
			if(object == null) return "0";
			String pid = object.getPid();
			if(pid != null && !pid.equals("")) return pid;
		}
		catch(Exception e) {
			//Fehler beim Lesen der pid -> weiter mit Rückgabe der id
		}
		try {
			return String.valueOf(getId());
		}
		catch(Exception ee) {
			return "<<" + ee.getMessage() + ">>";
		}
	}

	@Override
	public String getSuffixText() {
		/** kopiert aus {@link de.bsvrz.dav.daf.communication.dataRepresentation.data.info.version1.ReferenceDefinitionInfo} **/
		try {
			String name = null;
			String pid = null;
			String exceptionMessage = null;
			StringBuffer suffix = new StringBuffer();
			try {
				SystemObject object = getSystemObject();
				if(object == null) return "id (null)";
				name = object.getName();
				pid = object.getPid();
			}
			catch(Exception e) {
				exceptionMessage = " " + e.getLocalizedMessage();
			}
			if(pid == null || pid.equals("")) {
				suffix.append("id");
			}
			else {
				suffix.append("pid");
			}
			if(name != null && !name.equals("")) suffix.append(" (Name: ").append(name).append(")");
			if(exceptionMessage != null) suffix.append(" ").append(exceptionMessage);
			return suffix.toString();
		}
		catch(Exception ee) {
			return "<<" + ee.getMessage() + ">>";
		}
	}
}
