/*
 * Copyright 2005-2008 by beck et al. projects GmbH, Munich
 * Copyright 2009 by Kappich Systemberatung, Aachen
 * 
 * This file is part of de.bsvrz.pua.prot.
 * 
 * de.bsvrz.pua.prot is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * de.bsvrz.pua.prot is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.pua.prot.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.bsvrz.pua.prot.interpreter;

import antlr.CommonAST;
import antlr.Token;

/**
 * Erweitert {@link antlr.CommonAST} um das Abspeichern der Zeilennummer im Baum. Sonst wäre die Angabe von Zeilennummern bei Fehlermeldungen, die im {@link
 * de.bsvrz.pua.prot.interpreter.ProtocolTreeWalker} auftreten nicht möglich. Dient außerdem als Pretty-Printer
 *
 * @author beck et al. projects GmbH
 * @author Martin Hilgers
 * @version $Revision$ / $Date$ / ($Author$)
 */
public class AdvancedAST extends CommonAST {

	private static final long serialVersionUID = 9197201834572031877L;

	/** Zeilennummer. */
	private int _line = 0;

	/** Erzeugt einen Knoten ohne Zeilennummer-Information. */
	public AdvancedAST() {
		super();
	}

	/**
	 * Erzeugt einen Knoten mit Zeilennummer-Information.
	 *
	 * @param token Token aus dem der Knoten generiert wird.
	 */
	public AdvancedAST(Token token) {
		super(token);
	}

	/**
	 * Setzt die Zeilennummer-Information.
	 *
	 * @param token Token mit Zeilennummer-Information
	 *
	 * @see antlr.collections.AST#initialize(antlr.Token)
	 */
	@Override
    public void initialize(Token token) {
		super.initialize(token);
		_line = token.getLine();
	}

	/**
	 * Liefert die Zeilennummer zurück.
	 *
	 * @return Zeilennummer.
	 */
	@Override
    public int getLine() {
		return _line;
	}
}
