/*
 * Copyright 2005-2008 by beck et al. projects GmbH, Munich
 * Copyright 2009 by Kappich Systemberatung, Aachen
 * 
 * This file is part of de.bsvrz.pua.prot.
 * 
 * de.bsvrz.pua.prot is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * de.bsvrz.pua.prot is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.pua.prot.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.bsvrz.pua.prot.manager.taskmanager;

import de.bsvrz.dav.daf.main.config.SystemObject;
import de.bsvrz.sys.funclib.losb.exceptions.FailureException;

import java.util.List;

/**
 * Schnittstelle zum Task Manager Submodul. Anfragen, die in den Bereich Protokollerstellung fallen werden vom Manager Submodul an dieses Submodul
 * weitergereicht. ACHTUNG: Wird dieses Interface verändert, so muss der Feinentwurf angepasst werden!
 *
 * @author beck et al. projects GmbH
 * @author Martin Hilgers
 * @version $Revision$ / $Date$ / ($Author$)
 */
public interface TaskManagerInterface {

	/**
	 * Übergeben einer Anfrage an das Task Manager Submodul
	 *  @param client    Empfänger an den das Ergebnis der Anfrage gesendet werden soll
	 * @param id        Id der Anfrage
	 * @param operation Operationscode
	 * @param data      Byte-Feld mit serialisierten Anfragedaten
	 * @param initialFlowControl
	 */
	public void process(SystemObject client, long id, int operation, byte[] data, final long initialFlowControl);

	/**
	 * Fährt den Task-Manager herunter.
	 *
	 * @throws FailureException Fehler beim Herunterfahren.
	 */
	public void shutdown() throws FailureException;

	/**
	 * Liste mit den Protokollen die gerade gesendet / erstellt werden.
	 *
	 * @return Liste mit Protokollen. Falls keine Protokolle erstellt werden, wird ein Feld der Länge 0 zurückgegeben.
	 */
	public Long[] getActiveProtocols();

	/**
	 * Liste mit den Anfrage-Ids und zugehörigen Protokoll-Ids, die momentan in der Warteschlange liegen. Falls keine Anfragen vorliegen, wird ein Feld der Länge 0
	 * zurückgegeben.
	 *
	 * @return Liste
	 */
	public List<ThreadPool.QueuedThread> getWaitingProtocols();

	ThreadPool getPool();
}
